<?php

/**
 * @file
 * example_drush.drush.inc.
 */

/**
 * Implements hook_drush_command().
 */
function example_drush_drush_command() {
  $items = array();
  $items['delete-content'] = array(
    'description' => 'Delete test content',
    'drupal dependencies' => array('example_drush'),
    'aliases' => array('dc'),
    'arguments' => array(
      'type' => 'Nodes of this type will be deleted',
    ),
  );
  return $items;
}

/**
 * Deletes content of specific type.
 */
function drush_example_drush_delete_content($type) {
  if ($type) {
    $nids = db_query("SELECT nid FROM {node} WHERE type = :type", array(':type' => $type))->fetchCol();
    if ($nids) {
      $deleted = 0;
      foreach ($nids as $nid) {
        node_delete($nid);
        $deleted++;
        _drush_print_progress($deleted / count($nids));
      }
      $message = $deleted ? t('Quantity of deleted "@type" nodes: !qty', array('!qty' => $deleted, '@type' => $type)) : t('There are no nodes of type "@type"', array('@type' => $type));
    }
    else {
      $message = t('There are no nodes of specified content type.');
    }
    drush_print($message);
  }
  else {
    drush_print(t('Specify content type'));
  }
}

/**
 * Validate handler for delete-content command.
 */
function drush_example_drush_delete_content_validate($type) {
  $types = node_type_get_types();
  if ($type && !in_array($type, array_keys($types))) {
    return drush_set_error('error', t('Content type "@type" is not exists', array('@type' => $type)));
  }
}

/**
 * Provides progress bar.
 */
function _drush_print_progress($ratio) {
  $percentage = floor($ratio * 100) . '%';
  $columns = drush_get_context('DRUSH_COLUMNS', 80);
  // Subtract 8 characters for the percentage, brackets, spaces and arrow.
  $progress_columns = $columns - 8;
  // If ratio is 1 (complete), the > becomes a = to make a full bar.
  $arrow = ($ratio < 1) ? '>' : '=';
  // Print a new line if ratio is 1 (complete). Otherwise, use a CR.
  $line_ending = ($ratio < 1) ? "\r" : "\n";

  // Determine the current length of the progress string.
  $current_length = floor($ratio * $progress_columns);
  $progress_string = str_pad('', $current_length, '=');

  $output  = '[';
  $output .= $progress_string . $arrow;
  $output .= str_pad('', $progress_columns - $current_length);
  $output .= ']';
  $output .= str_pad('', 5 - strlen($percentage)) . $percentage;
  $output .= $line_ending;

  print $output;
}
